@@ -20,7 +20,7 @@ predict_problinkem.cluster_pairs <- function(pairs, model, type, binary, add,
       pairs <- env$pairs
     } 
     predict(model, newdata = pairs, type = type, binary = binary, 
-      add = TRUE, comparators = comparators)
+      add = TRUE, comparators = comparators, inplace = TRUE)
     TRUE
   }, name = pairs$name, model = model, type = type, binary = binary, 
     comparators = comparators, new_name = new_name)
