@@ -1,4 +1,5 @@
 library(reclin2)
+source("helpers.R")
 
 message("Testing compare_vars()")
 
@@ -32,8 +33,8 @@ stopifnot(isTRUE(all.equal(as.logical(tmp$fooc), tmp2)))
 # vectors
 testfun <- function(a, b) {
   data.table(
-    jw = jaro_winkler()(a,b),
-    ja = jaccard()(a,b)
+    jw = cmp_jarowinkler()(a,b),
+    ja = cmp_jaccard()(a,b)
   )
 }
 tmp <- compare_vars(pairs, "foo", "bar", "bar", testfun)
@@ -66,4 +67,19 @@ tmp2 <- x$foo[pairs$.x] == y$foo[pairs$.y]
 stopifnot(is.logical(tmp$foo))
 stopifnot(isTRUE(all.equal(as.logical(tmp$foo), tmp2)))
 
+# Passing additional arguments on to the comparison function
+x <- data.table(foo = 1:3, bar = c("aa", "bb", "cc"))
+y <- data.table(foo = 3:4, bar = c("cc", "dd"))
+pairs <- pair(x, y)
+
+testfun <- function(x, y, foo = 1) {
+  rep(foo, length(x))
+}
+tmp <- compare_vars(pairs, "foo", comparator = testfun)
+expect_equal(tmp$foo, rep(1, 6), attributes = FALSE)
+tmp <- compare_vars(pairs, "foo", comparator = testfun, foo = 5)
+expect_equal(tmp$foo, rep(5, 6), attributes = FALSE)
+
 message("Testing compare_vars() successful")
+
+
